#!/usr/bin/perl

use warnings;
use strict;

use Data::Dumper;

require "ldap-netgroups.pl";

use constant ADD_NETGROUP => 1;
use constant DELETE_NETGROUP => 2;
use constant ADD_SUBGROUP => 3;
use constant DELETE_SUBGROUP => 4;
use constant ADD_TRIPLE => 5;
use constant DELETE_TRIPLE => 6;

ldap_connect('ldap');

my($basedn, $rootdn, $rootpw) = ('dc=skole,dc=skolelinux,dc=no','cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no','kaljdf');

my $queue = [
	      { action => ADD_NETGROUP, netgroup => "no-hosts" },
	      { action => ADD_TRIPLE, netgroup => "no-hosts", triples => ["(vg.no,-,-)","(dagbladet.no,-,-)","(aftenposten.no,-,-)"] },
	      { action => DELETE_TRIPLE, netgroup => "no-hosts", triples => ["(vg.no,-,-)","(dagbladet.no,-,-)"] },
	      { action => ADD_SUBGROUP, netgroup => "no-hosts", subgroups => ["all-hosts","jallaballa", "no-hosts"] },
	      { action => DELETE_SUBGROUP, netgroup => "no-hosts", subgroups => ["no-hosts",  "all-hosts"] },
	      { action => DELETE_NETGROUP, netgroup => "no-hosts" },
];

foreach my $action ( @{$queue} ) {
   if($action->{action} == ADD_NETGROUP) {
     print "Trying to add netgroup\n";
     ldap_netgroup_add({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup} });
   } elsif($action->{action} == DELETE_NETGROUP) {
     print "Trying to delete netgroup\n";
     ldap_netgroup_delete({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup} });
   } elsif($action->{action} == ADD_TRIPLE) {
     print "Trying to add triple\n";
     ldap_netgroup_addtriple({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup}, triples => $action->{triples} });
   } elsif($action->{action} == DELETE_TRIPLE) {
     print "Trying to delete triple\n";
     ldap_netgroup_rmtriple({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup}, triples => $action->{triples} });
   } elsif($action->{action} == ADD_SUBGROUP) {
     print "Trying to add subgroup\n";
     print ldap_netgroup_addsubgroup({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup}, subgroups => $action->{subgroups} })->error;
   } elsif($action->{action} == DELETE_SUBGROUP) {
     print "Trying to delete subgroup\n";
     print ldap_netgroup_rmsubgroup({ basedn => $basedn, rootdn => $rootdn, rootpw => $rootpw, cn => $action->{netgroup}, subgroups => $action->{subgroups} })->error;
   } else {
     next;
   }
}
